How to cite pyGPCCA
-------------------
If you use *pyGPCCA* or parts of it to model molecular dynamics, e.g.
to coarse-grain protein conformational dynamics, cite [`Reuter18`_] as:

.. code-block:: bibtex

    @article{Reuter18,
        author = {Reuter, Bernhard and Weber, Marcus and Fackeldey, Konstantin and Röblitz, Susanna and Garcia, Martin E.},
        title = {Generalized Markov State Modeling Method for Nonequilibrium Biomolecular Dynamics:
        Exemplified on Amyloid β Conformational Dynamics Driven by an Oscillating Electric Field},
        journal = {Journal of Chemical Theory and Computation},
        volume = {14},
        number = {7},
        pages = {3579-3594},
        year = {2018},
        doi = {10.1021/acs.jctc.8b00079},
        note  = {PMID: 29812922},
    }

If you use *pyGPCCA* or parts of it in a more general context,
e.g. to model cellular dynamics, cite [`Reuter19`_] as:

.. code-block:: bibtex

    @article{Reuter19,
        author = {Reuter,Bernhard and Fackeldey,Konstantin and Weber,Marcus },
        title = {Generalized Markov modeling of nonreversible molecular kinetics},
        journal = {The Journal of Chemical Physics},
        volume = {150},
        number = {17},
        pages = {174103},
        year = {2019},
        doi = {10.1063/1.5064530},
    }

Please also consider to cite the appropriate version of the *pyGPCCA* package as deposited on Zenodo [`Reuter22`_].

.. _Reuter18: https://pubs.acs.org/doi/abs/10.1021/acs.jctc.8b00079
.. _Reuter19: https://doi.org/10.1063/1.5064530
.. _Reuter22: https://doi.org/10.5281/zenodo.6913970
